# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.field_group import FieldGroup  # noqa: F401,E501
from demisto_client.demisto_api.models.grid_column import GridColumn  # noqa: F401,E501


class IncidentField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'associated_to_all': 'bool',
        'associated_types': 'list[str]',
        'breach_script': 'str',
        'case_insensitive': 'bool',
        'cli_name': 'str',
        'close_form': 'bool',
        'columns': 'list[GridColumn]',
        'commit_message': 'str',
        'content': 'bool',
        'default_rows': 'list[dict(str, object)]',
        'description': 'str',
        'edit_form': 'bool',
        'field_calc_script': 'str',
        'group': 'FieldGroup',
        'hidden': 'bool',
        'id': 'str',
        'is_read_only': 'bool',
        'locked': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'never_set_as_required': 'bool',
        'owner_only': 'bool',
        'placeholder': 'str',
        'prev_name': 'str',
        'required': 'bool',
        'script': 'str',
        'select_values': 'list[str]',
        'should_commit': 'bool',
        'sla': 'int',
        'sort_values': 'list[str]',
        'system': 'bool',
        'system_associated_types': 'list[str]',
        'threshold': 'float',
        'type': 'str',
        'unmapped': 'bool',
        'unsearchable': 'bool',
        'use_as_kpi': 'bool',
        'validated_error': 'str',
        'validation_regex': 'str',
        'vc_should_ignore': 'bool',
        'version': 'int'
    }

    attribute_map = {
        'associated_to_all': 'associatedToAll',
        'associated_types': 'associatedTypes',
        'breach_script': 'breachScript',
        'case_insensitive': 'caseInsensitive',
        'cli_name': 'cliName',
        'close_form': 'closeForm',
        'columns': 'columns',
        'commit_message': 'commitMessage',
        'content': 'content',
        'default_rows': 'defaultRows',
        'description': 'description',
        'edit_form': 'editForm',
        'field_calc_script': 'fieldCalcScript',
        'group': 'group',
        'hidden': 'hidden',
        'id': 'id',
        'is_read_only': 'isReadOnly',
        'locked': 'locked',
        'modified': 'modified',
        'name': 'name',
        'never_set_as_required': 'neverSetAsRequired',
        'owner_only': 'ownerOnly',
        'placeholder': 'placeholder',
        'prev_name': 'prevName',
        'required': 'required',
        'script': 'script',
        'select_values': 'selectValues',
        'should_commit': 'shouldCommit',
        'sla': 'sla',
        'sort_values': 'sortValues',
        'system': 'system',
        'system_associated_types': 'systemAssociatedTypes',
        'threshold': 'threshold',
        'type': 'type',
        'unmapped': 'unmapped',
        'unsearchable': 'unsearchable',
        'use_as_kpi': 'useAsKpi',
        'validated_error': 'validatedError',
        'validation_regex': 'validationRegex',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version'
    }

    def __init__(self, associated_to_all=None, associated_types=None, breach_script=None, case_insensitive=None, cli_name=None, close_form=None, columns=None, commit_message=None, content=None, default_rows=None, description=None, edit_form=None, field_calc_script=None, group=None, hidden=None, id=None, is_read_only=None, locked=None, modified=None, name=None, never_set_as_required=None, owner_only=None, placeholder=None, prev_name=None, required=None, script=None, select_values=None, should_commit=None, sla=None, sort_values=None, system=None, system_associated_types=None, threshold=None, type=None, unmapped=None, unsearchable=None, use_as_kpi=None, validated_error=None, validation_regex=None, vc_should_ignore=None, version=None):  # noqa: E501
        """IncidentField - a model defined in Swagger"""  # noqa: E501

        self._associated_to_all = None
        self._associated_types = None
        self._breach_script = None
        self._case_insensitive = None
        self._cli_name = None
        self._close_form = None
        self._columns = None
        self._commit_message = None
        self._content = None
        self._default_rows = None
        self._description = None
        self._edit_form = None
        self._field_calc_script = None
        self._group = None
        self._hidden = None
        self._id = None
        self._is_read_only = None
        self._locked = None
        self._modified = None
        self._name = None
        self._never_set_as_required = None
        self._owner_only = None
        self._placeholder = None
        self._prev_name = None
        self._required = None
        self._script = None
        self._select_values = None
        self._should_commit = None
        self._sla = None
        self._sort_values = None
        self._system = None
        self._system_associated_types = None
        self._threshold = None
        self._type = None
        self._unmapped = None
        self._unsearchable = None
        self._use_as_kpi = None
        self._validated_error = None
        self._validation_regex = None
        self._vc_should_ignore = None
        self._version = None
        self.discriminator = None

        if associated_to_all is not None:
            self.associated_to_all = associated_to_all
        if associated_types is not None:
            self.associated_types = associated_types
        if breach_script is not None:
            self.breach_script = breach_script
        if case_insensitive is not None:
            self.case_insensitive = case_insensitive
        if cli_name is not None:
            self.cli_name = cli_name
        if close_form is not None:
            self.close_form = close_form
        if columns is not None:
            self.columns = columns
        if commit_message is not None:
            self.commit_message = commit_message
        if content is not None:
            self.content = content
        if default_rows is not None:
            self.default_rows = default_rows
        if description is not None:
            self.description = description
        if edit_form is not None:
            self.edit_form = edit_form
        if field_calc_script is not None:
            self.field_calc_script = field_calc_script
        if group is not None:
            self.group = group
        if hidden is not None:
            self.hidden = hidden
        if id is not None:
            self.id = id
        if is_read_only is not None:
            self.is_read_only = is_read_only
        if locked is not None:
            self.locked = locked
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if never_set_as_required is not None:
            self.never_set_as_required = never_set_as_required
        if owner_only is not None:
            self.owner_only = owner_only
        if placeholder is not None:
            self.placeholder = placeholder
        if prev_name is not None:
            self.prev_name = prev_name
        if required is not None:
            self.required = required
        if script is not None:
            self.script = script
        if select_values is not None:
            self.select_values = select_values
        if should_commit is not None:
            self.should_commit = should_commit
        if sla is not None:
            self.sla = sla
        if sort_values is not None:
            self.sort_values = sort_values
        if system is not None:
            self.system = system
        if system_associated_types is not None:
            self.system_associated_types = system_associated_types
        if threshold is not None:
            self.threshold = threshold
        if type is not None:
            self.type = type
        if unmapped is not None:
            self.unmapped = unmapped
        if unsearchable is not None:
            self.unsearchable = unsearchable
        if use_as_kpi is not None:
            self.use_as_kpi = use_as_kpi
        if validated_error is not None:
            self.validated_error = validated_error
        if validation_regex is not None:
            self.validation_regex = validation_regex
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version

    @property
    def associated_to_all(self):
        """Gets the associated_to_all of this IncidentField.  # noqa: E501


        :return: The associated_to_all of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._associated_to_all

    @associated_to_all.setter
    def associated_to_all(self, associated_to_all):
        """Sets the associated_to_all of this IncidentField.


        :param associated_to_all: The associated_to_all of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._associated_to_all = associated_to_all

    @property
    def associated_types(self):
        """Gets the associated_types of this IncidentField.  # noqa: E501

        AssociatedTypes - list of incident (case) types IDs related to specific incident field  # noqa: E501

        :return: The associated_types of this IncidentField.  # noqa: E501
        :rtype: list[str]
        """
        return self._associated_types

    @associated_types.setter
    def associated_types(self, associated_types):
        """Sets the associated_types of this IncidentField.

        AssociatedTypes - list of incident (case) types IDs related to specific incident field  # noqa: E501

        :param associated_types: The associated_types of this IncidentField.  # noqa: E501
        :type: list[str]
        """

        self._associated_types = associated_types

    @property
    def breach_script(self):
        """Gets the breach_script of this IncidentField.  # noqa: E501


        :return: The breach_script of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._breach_script

    @breach_script.setter
    def breach_script(self, breach_script):
        """Sets the breach_script of this IncidentField.


        :param breach_script: The breach_script of this IncidentField.  # noqa: E501
        :type: str
        """

        self._breach_script = breach_script

    @property
    def case_insensitive(self):
        """Gets the case_insensitive of this IncidentField.  # noqa: E501


        :return: The case_insensitive of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._case_insensitive

    @case_insensitive.setter
    def case_insensitive(self, case_insensitive):
        """Sets the case_insensitive of this IncidentField.


        :param case_insensitive: The case_insensitive of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._case_insensitive = case_insensitive

    @property
    def cli_name(self):
        """Gets the cli_name of this IncidentField.  # noqa: E501


        :return: The cli_name of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._cli_name

    @cli_name.setter
    def cli_name(self, cli_name):
        """Sets the cli_name of this IncidentField.


        :param cli_name: The cli_name of this IncidentField.  # noqa: E501
        :type: str
        """

        self._cli_name = cli_name

    @property
    def close_form(self):
        """Gets the close_form of this IncidentField.  # noqa: E501


        :return: The close_form of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._close_form

    @close_form.setter
    def close_form(self, close_form):
        """Sets the close_form of this IncidentField.


        :param close_form: The close_form of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._close_form = close_form

    @property
    def columns(self):
        """Gets the columns of this IncidentField.  # noqa: E501


        :return: The columns of this IncidentField.  # noqa: E501
        :rtype: list[GridColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this IncidentField.


        :param columns: The columns of this IncidentField.  # noqa: E501
        :type: list[GridColumn]
        """

        self._columns = columns

    @property
    def commit_message(self):
        """Gets the commit_message of this IncidentField.  # noqa: E501


        :return: The commit_message of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this IncidentField.


        :param commit_message: The commit_message of this IncidentField.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def content(self):
        """Gets the content of this IncidentField.  # noqa: E501


        :return: The content of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this IncidentField.


        :param content: The content of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._content = content

    @property
    def default_rows(self):
        """Gets the default_rows of this IncidentField.  # noqa: E501


        :return: The default_rows of this IncidentField.  # noqa: E501
        :rtype: list[dict(str, object)]
        """
        return self._default_rows

    @default_rows.setter
    def default_rows(self, default_rows):
        """Sets the default_rows of this IncidentField.


        :param default_rows: The default_rows of this IncidentField.  # noqa: E501
        :type: list[dict(str, object)]
        """

        self._default_rows = default_rows

    @property
    def description(self):
        """Gets the description of this IncidentField.  # noqa: E501


        :return: The description of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this IncidentField.


        :param description: The description of this IncidentField.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def edit_form(self):
        """Gets the edit_form of this IncidentField.  # noqa: E501


        :return: The edit_form of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._edit_form

    @edit_form.setter
    def edit_form(self, edit_form):
        """Sets the edit_form of this IncidentField.


        :param edit_form: The edit_form of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._edit_form = edit_form

    @property
    def field_calc_script(self):
        """Gets the field_calc_script of this IncidentField.  # noqa: E501


        :return: The field_calc_script of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._field_calc_script

    @field_calc_script.setter
    def field_calc_script(self, field_calc_script):
        """Sets the field_calc_script of this IncidentField.


        :param field_calc_script: The field_calc_script of this IncidentField.  # noqa: E501
        :type: str
        """

        self._field_calc_script = field_calc_script

    @property
    def group(self):
        """Gets the group of this IncidentField.  # noqa: E501


        :return: The group of this IncidentField.  # noqa: E501
        :rtype: FieldGroup
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this IncidentField.


        :param group: The group of this IncidentField.  # noqa: E501
        :type: FieldGroup
        """

        self._group = group

    @property
    def hidden(self):
        """Gets the hidden of this IncidentField.  # noqa: E501


        :return: The hidden of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this IncidentField.


        :param hidden: The hidden of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def id(self):
        """Gets the id of this IncidentField.  # noqa: E501


        :return: The id of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IncidentField.


        :param id: The id of this IncidentField.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_read_only(self):
        """Gets the is_read_only of this IncidentField.  # noqa: E501


        :return: The is_read_only of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._is_read_only

    @is_read_only.setter
    def is_read_only(self, is_read_only):
        """Sets the is_read_only of this IncidentField.


        :param is_read_only: The is_read_only of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._is_read_only = is_read_only

    @property
    def locked(self):
        """Gets the locked of this IncidentField.  # noqa: E501


        :return: The locked of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this IncidentField.


        :param locked: The locked of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def modified(self):
        """Gets the modified of this IncidentField.  # noqa: E501


        :return: The modified of this IncidentField.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this IncidentField.


        :param modified: The modified of this IncidentField.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this IncidentField.  # noqa: E501


        :return: The name of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IncidentField.


        :param name: The name of this IncidentField.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def never_set_as_required(self):
        """Gets the never_set_as_required of this IncidentField.  # noqa: E501


        :return: The never_set_as_required of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._never_set_as_required

    @never_set_as_required.setter
    def never_set_as_required(self, never_set_as_required):
        """Sets the never_set_as_required of this IncidentField.


        :param never_set_as_required: The never_set_as_required of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._never_set_as_required = never_set_as_required

    @property
    def owner_only(self):
        """Gets the owner_only of this IncidentField.  # noqa: E501


        :return: The owner_only of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._owner_only

    @owner_only.setter
    def owner_only(self, owner_only):
        """Sets the owner_only of this IncidentField.


        :param owner_only: The owner_only of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._owner_only = owner_only

    @property
    def placeholder(self):
        """Gets the placeholder of this IncidentField.  # noqa: E501


        :return: The placeholder of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._placeholder

    @placeholder.setter
    def placeholder(self, placeholder):
        """Sets the placeholder of this IncidentField.


        :param placeholder: The placeholder of this IncidentField.  # noqa: E501
        :type: str
        """

        self._placeholder = placeholder

    @property
    def prev_name(self):
        """Gets the prev_name of this IncidentField.  # noqa: E501


        :return: The prev_name of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this IncidentField.


        :param prev_name: The prev_name of this IncidentField.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def required(self):
        """Gets the required of this IncidentField.  # noqa: E501


        :return: The required of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this IncidentField.


        :param required: The required of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def script(self):
        """Gets the script of this IncidentField.  # noqa: E501


        :return: The script of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this IncidentField.


        :param script: The script of this IncidentField.  # noqa: E501
        :type: str
        """

        self._script = script

    @property
    def select_values(self):
        """Gets the select_values of this IncidentField.  # noqa: E501


        :return: The select_values of this IncidentField.  # noqa: E501
        :rtype: list[str]
        """
        return self._select_values

    @select_values.setter
    def select_values(self, select_values):
        """Sets the select_values of this IncidentField.


        :param select_values: The select_values of this IncidentField.  # noqa: E501
        :type: list[str]
        """

        self._select_values = select_values

    @property
    def should_commit(self):
        """Gets the should_commit of this IncidentField.  # noqa: E501


        :return: The should_commit of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this IncidentField.


        :param should_commit: The should_commit of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sla(self):
        """Gets the sla of this IncidentField.  # noqa: E501


        :return: The sla of this IncidentField.  # noqa: E501
        :rtype: int
        """
        return self._sla

    @sla.setter
    def sla(self, sla):
        """Sets the sla of this IncidentField.


        :param sla: The sla of this IncidentField.  # noqa: E501
        :type: int
        """

        self._sla = sla

    @property
    def sort_values(self):
        """Gets the sort_values of this IncidentField.  # noqa: E501


        :return: The sort_values of this IncidentField.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this IncidentField.


        :param sort_values: The sort_values of this IncidentField.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def system(self):
        """Gets the system of this IncidentField.  # noqa: E501


        :return: The system of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this IncidentField.


        :param system: The system of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def system_associated_types(self):
        """Gets the system_associated_types of this IncidentField.  # noqa: E501


        :return: The system_associated_types of this IncidentField.  # noqa: E501
        :rtype: list[str]
        """
        return self._system_associated_types

    @system_associated_types.setter
    def system_associated_types(self, system_associated_types):
        """Sets the system_associated_types of this IncidentField.


        :param system_associated_types: The system_associated_types of this IncidentField.  # noqa: E501
        :type: list[str]
        """

        self._system_associated_types = system_associated_types

    @property
    def threshold(self):
        """Gets the threshold of this IncidentField.  # noqa: E501


        :return: The threshold of this IncidentField.  # noqa: E501
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this IncidentField.


        :param threshold: The threshold of this IncidentField.  # noqa: E501
        :type: float
        """

        self._threshold = threshold

    @property
    def type(self):
        """Gets the type of this IncidentField.  # noqa: E501


        :return: The type of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this IncidentField.


        :param type: The type of this IncidentField.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def unmapped(self):
        """Gets the unmapped of this IncidentField.  # noqa: E501


        :return: The unmapped of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._unmapped

    @unmapped.setter
    def unmapped(self, unmapped):
        """Sets the unmapped of this IncidentField.


        :param unmapped: The unmapped of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._unmapped = unmapped

    @property
    def unsearchable(self):
        """Gets the unsearchable of this IncidentField.  # noqa: E501


        :return: The unsearchable of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._unsearchable

    @unsearchable.setter
    def unsearchable(self, unsearchable):
        """Sets the unsearchable of this IncidentField.


        :param unsearchable: The unsearchable of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._unsearchable = unsearchable

    @property
    def use_as_kpi(self):
        """Gets the use_as_kpi of this IncidentField.  # noqa: E501


        :return: The use_as_kpi of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._use_as_kpi

    @use_as_kpi.setter
    def use_as_kpi(self, use_as_kpi):
        """Sets the use_as_kpi of this IncidentField.


        :param use_as_kpi: The use_as_kpi of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._use_as_kpi = use_as_kpi

    @property
    def validated_error(self):
        """Gets the validated_error of this IncidentField.  # noqa: E501


        :return: The validated_error of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._validated_error

    @validated_error.setter
    def validated_error(self, validated_error):
        """Sets the validated_error of this IncidentField.


        :param validated_error: The validated_error of this IncidentField.  # noqa: E501
        :type: str
        """

        self._validated_error = validated_error

    @property
    def validation_regex(self):
        """Gets the validation_regex of this IncidentField.  # noqa: E501


        :return: The validation_regex of this IncidentField.  # noqa: E501
        :rtype: str
        """
        return self._validation_regex

    @validation_regex.setter
    def validation_regex(self, validation_regex):
        """Sets the validation_regex of this IncidentField.


        :param validation_regex: The validation_regex of this IncidentField.  # noqa: E501
        :type: str
        """

        self._validation_regex = validation_regex

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this IncidentField.  # noqa: E501


        :return: The vc_should_ignore of this IncidentField.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this IncidentField.


        :param vc_should_ignore: The vc_should_ignore of this IncidentField.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this IncidentField.  # noqa: E501


        :return: The version of this IncidentField.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this IncidentField.


        :param version: The version of this IncidentField.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IncidentField, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncidentField):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DBotScore(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content': 'str',
        'content_format': 'str',
        'context': 'dict(str, object)',
        'is_typed_indicator': 'bool',
        'score': 'int',
        'score_change_timestamp': 'datetime',
        'timestamp': 'datetime',
        'type': 'str'
    }

    attribute_map = {
        'content': 'content',
        'content_format': 'contentFormat',
        'context': 'context',
        'is_typed_indicator': 'isTypedIndicator',
        'score': 'score',
        'score_change_timestamp': 'scoreChangeTimestamp',
        'timestamp': 'timestamp',
        'type': 'type'
    }

    def __init__(self, content=None, content_format=None, context=None, is_typed_indicator=None, score=None, score_change_timestamp=None, timestamp=None, type=None):  # noqa: E501
        """DBotScore - a model defined in Swagger"""  # noqa: E501

        self._content = None
        self._content_format = None
        self._context = None
        self._is_typed_indicator = None
        self._score = None
        self._score_change_timestamp = None
        self._timestamp = None
        self._type = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if content_format is not None:
            self.content_format = content_format
        if context is not None:
            self.context = context
        if is_typed_indicator is not None:
            self.is_typed_indicator = is_typed_indicator
        if score is not None:
            self.score = score
        if score_change_timestamp is not None:
            self.score_change_timestamp = score_change_timestamp
        if timestamp is not None:
            self.timestamp = timestamp
        if type is not None:
            self.type = type

    @property
    def content(self):
        """Gets the content of this DBotScore.  # noqa: E501


        :return: The content of this DBotScore.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this DBotScore.


        :param content: The content of this DBotScore.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def content_format(self):
        """Gets the content_format of this DBotScore.  # noqa: E501


        :return: The content_format of this DBotScore.  # noqa: E501
        :rtype: str
        """
        return self._content_format

    @content_format.setter
    def content_format(self, content_format):
        """Sets the content_format of this DBotScore.


        :param content_format: The content_format of this DBotScore.  # noqa: E501
        :type: str
        """

        self._content_format = content_format

    @property
    def context(self):
        """Gets the context of this DBotScore.  # noqa: E501


        :return: The context of this DBotScore.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this DBotScore.


        :param context: The context of this DBotScore.  # noqa: E501
        :type: dict(str, object)
        """

        self._context = context

    @property
    def is_typed_indicator(self):
        """Gets the is_typed_indicator of this DBotScore.  # noqa: E501


        :return: The is_typed_indicator of this DBotScore.  # noqa: E501
        :rtype: bool
        """
        return self._is_typed_indicator

    @is_typed_indicator.setter
    def is_typed_indicator(self, is_typed_indicator):
        """Sets the is_typed_indicator of this DBotScore.


        :param is_typed_indicator: The is_typed_indicator of this DBotScore.  # noqa: E501
        :type: bool
        """

        self._is_typed_indicator = is_typed_indicator

    @property
    def score(self):
        """Gets the score of this DBotScore.  # noqa: E501


        :return: The score of this DBotScore.  # noqa: E501
        :rtype: int
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this DBotScore.


        :param score: The score of this DBotScore.  # noqa: E501
        :type: int
        """

        self._score = score

    @property
    def score_change_timestamp(self):
        """Gets the score_change_timestamp of this DBotScore.  # noqa: E501

        We need to track when the score changes to know if we need to re-calculate the overall score  # noqa: E501

        :return: The score_change_timestamp of this DBotScore.  # noqa: E501
        :rtype: datetime
        """
        return self._score_change_timestamp

    @score_change_timestamp.setter
    def score_change_timestamp(self, score_change_timestamp):
        """Sets the score_change_timestamp of this DBotScore.

        We need to track when the score changes to know if we need to re-calculate the overall score  # noqa: E501

        :param score_change_timestamp: The score_change_timestamp of this DBotScore.  # noqa: E501
        :type: datetime
        """

        self._score_change_timestamp = score_change_timestamp

    @property
    def timestamp(self):
        """Gets the timestamp of this DBotScore.  # noqa: E501


        :return: The timestamp of this DBotScore.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this DBotScore.


        :param timestamp: The timestamp of this DBotScore.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def type(self):
        """Gets the type of this DBotScore.  # noqa: E501


        :return: The type of this DBotScore.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DBotScore.


        :param type: The type of this DBotScore.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DBotScore, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DBotScore):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.output_type import OutputType  # noqa: F401,E501


class Output(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content_path': 'str',
        'context_path': 'str',
        'description': 'object',
        'type': 'OutputType'
    }

    attribute_map = {
        'content_path': 'contentPath',
        'context_path': 'contextPath',
        'description': 'description',
        'type': 'type'
    }

    def __init__(self, content_path=None, context_path=None, description=None, type=None):  # noqa: E501
        """Output - a model defined in Swagger"""  # noqa: E501

        self._content_path = None
        self._context_path = None
        self._description = None
        self._type = None
        self.discriminator = None

        if content_path is not None:
            self.content_path = content_path
        if context_path is not None:
            self.context_path = context_path
        if description is not None:
            self.description = description
        if type is not None:
            self.type = type

    @property
    def content_path(self):
        """Gets the content_path of this Output.  # noqa: E501


        :return: The content_path of this Output.  # noqa: E501
        :rtype: str
        """
        return self._content_path

    @content_path.setter
    def content_path(self, content_path):
        """Sets the content_path of this Output.


        :param content_path: The content_path of this Output.  # noqa: E501
        :type: str
        """

        self._content_path = content_path

    @property
    def context_path(self):
        """Gets the context_path of this Output.  # noqa: E501


        :return: The context_path of this Output.  # noqa: E501
        :rtype: str
        """
        return self._context_path

    @context_path.setter
    def context_path(self, context_path):
        """Sets the context_path of this Output.


        :param context_path: The context_path of this Output.  # noqa: E501
        :type: str
        """

        self._context_path = context_path

    @property
    def description(self):
        """Gets the description of this Output.  # noqa: E501

        Description is either a string or a map from string to interface  # noqa: E501

        :return: The description of this Output.  # noqa: E501
        :rtype: object
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Output.

        Description is either a string or a map from string to interface  # noqa: E501

        :param description: The description of this Output.  # noqa: E501
        :type: object
        """

        self._description = description

    @property
    def type(self):
        """Gets the type of this Output.  # noqa: E501


        :return: The type of this Output.  # noqa: E501
        :rtype: OutputType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Output.


        :param type: The type of this Output.  # noqa: E501
        :type: OutputType
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Output, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Output):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.question import Question  # noqa: F401,E501


class DataCollectionForm(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'expired': 'bool',
        'questions': 'list[Question]',
        'sender': 'str',
        'title': 'str',
        'total_answers': 'int'
    }

    attribute_map = {
        'description': 'description',
        'expired': 'expired',
        'questions': 'questions',
        'sender': 'sender',
        'title': 'title',
        'total_answers': 'totalAnswers'
    }

    def __init__(self, description=None, expired=None, questions=None, sender=None, title=None, total_answers=None):  # noqa: E501
        """DataCollectionForm - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._expired = None
        self._questions = None
        self._sender = None
        self._title = None
        self._total_answers = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if expired is not None:
            self.expired = expired
        if questions is not None:
            self.questions = questions
        if sender is not None:
            self.sender = sender
        if title is not None:
            self.title = title
        if total_answers is not None:
            self.total_answers = total_answers

    @property
    def description(self):
        """Gets the description of this DataCollectionForm.  # noqa: E501


        :return: The description of this DataCollectionForm.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DataCollectionForm.


        :param description: The description of this DataCollectionForm.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def expired(self):
        """Gets the expired of this DataCollectionForm.  # noqa: E501


        :return: The expired of this DataCollectionForm.  # noqa: E501
        :rtype: bool
        """
        return self._expired

    @expired.setter
    def expired(self, expired):
        """Sets the expired of this DataCollectionForm.


        :param expired: The expired of this DataCollectionForm.  # noqa: E501
        :type: bool
        """

        self._expired = expired

    @property
    def questions(self):
        """Gets the questions of this DataCollectionForm.  # noqa: E501


        :return: The questions of this DataCollectionForm.  # noqa: E501
        :rtype: list[Question]
        """
        return self._questions

    @questions.setter
    def questions(self, questions):
        """Sets the questions of this DataCollectionForm.


        :param questions: The questions of this DataCollectionForm.  # noqa: E501
        :type: list[Question]
        """

        self._questions = questions

    @property
    def sender(self):
        """Gets the sender of this DataCollectionForm.  # noqa: E501


        :return: The sender of this DataCollectionForm.  # noqa: E501
        :rtype: str
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this DataCollectionForm.


        :param sender: The sender of this DataCollectionForm.  # noqa: E501
        :type: str
        """

        self._sender = sender

    @property
    def title(self):
        """Gets the title of this DataCollectionForm.  # noqa: E501


        :return: The title of this DataCollectionForm.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DataCollectionForm.


        :param title: The title of this DataCollectionForm.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def total_answers(self):
        """Gets the total_answers of this DataCollectionForm.  # noqa: E501


        :return: The total_answers of this DataCollectionForm.  # noqa: E501
        :rtype: int
        """
        return self._total_answers

    @total_answers.setter
    def total_answers(self, total_answers):
        """Sets the total_answers of this DataCollectionForm.


        :param total_answers: The total_answers of this DataCollectionForm.  # noqa: E501
        :type: int
        """

        self._total_answers = total_answers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataCollectionForm, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataCollectionForm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.investigation_playbook_state import InvestigationPlaybookState  # noqa: F401,E501
from demisto_client.demisto_api.models.investigation_playbook_task import InvestigationPlaybookTask  # noqa: F401,E501
from demisto_client.demisto_api.models.playbook_inputs import PlaybookInputs  # noqa: F401,E501
from demisto_client.demisto_api.models.playbook_outputs import PlaybookOutputs  # noqa: F401,E501
from demisto_client.demisto_api.models.playbook_view import PlaybookView  # noqa: F401,E501


class InvestigationPlaybookData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ready_playbook_inputs': 'dict(str, dict(str, object))',
        'auto_extracting': 'bool',
        'comment': 'str',
        'inputs': 'PlaybookInputs',
        'investigation_id': 'str',
        'name': 'str',
        'outputs': 'PlaybookOutputs',
        'playbook_id': 'str',
        'start_date': 'datetime',
        'start_task_id': 'str',
        'state': 'InvestigationPlaybookState',
        'sub_playbook_inputs': 'dict(str, PlaybookInputs)',
        'sub_playbook_outputs': 'dict(str, PlaybookOutputs)',
        'tasks': 'dict(str, InvestigationPlaybookTask)',
        'view': 'PlaybookView'
    }

    attribute_map = {
        'ready_playbook_inputs': 'ReadyPlaybookInputs',
        'auto_extracting': 'autoExtracting',
        'comment': 'comment',
        'inputs': 'inputs',
        'investigation_id': 'investigationId',
        'name': 'name',
        'outputs': 'outputs',
        'playbook_id': 'playbookId',
        'start_date': 'startDate',
        'start_task_id': 'startTaskId',
        'state': 'state',
        'sub_playbook_inputs': 'subPlaybookInputs',
        'sub_playbook_outputs': 'subPlaybookOutputs',
        'tasks': 'tasks',
        'view': 'view'
    }

    def __init__(self, ready_playbook_inputs=None, auto_extracting=None, comment=None, inputs=None, investigation_id=None, name=None, outputs=None, playbook_id=None, start_date=None, start_task_id=None, state=None, sub_playbook_inputs=None, sub_playbook_outputs=None, tasks=None, view=None):  # noqa: E501
        """InvestigationPlaybookData - a model defined in Swagger"""  # noqa: E501

        self._ready_playbook_inputs = None
        self._auto_extracting = None
        self._comment = None
        self._inputs = None
        self._investigation_id = None
        self._name = None
        self._outputs = None
        self._playbook_id = None
        self._start_date = None
        self._start_task_id = None
        self._state = None
        self._sub_playbook_inputs = None
        self._sub_playbook_outputs = None
        self._tasks = None
        self._view = None
        self.discriminator = None

        if ready_playbook_inputs is not None:
            self.ready_playbook_inputs = ready_playbook_inputs
        if auto_extracting is not None:
            self.auto_extracting = auto_extracting
        if comment is not None:
            self.comment = comment
        if inputs is not None:
            self.inputs = inputs
        if investigation_id is not None:
            self.investigation_id = investigation_id
        if name is not None:
            self.name = name
        if outputs is not None:
            self.outputs = outputs
        if playbook_id is not None:
            self.playbook_id = playbook_id
        if start_date is not None:
            self.start_date = start_date
        if start_task_id is not None:
            self.start_task_id = start_task_id
        if state is not None:
            self.state = state
        if sub_playbook_inputs is not None:
            self.sub_playbook_inputs = sub_playbook_inputs
        if sub_playbook_outputs is not None:
            self.sub_playbook_outputs = sub_playbook_outputs
        if tasks is not None:
            self.tasks = tasks
        if view is not None:
            self.view = view

    @property
    def ready_playbook_inputs(self):
        """Gets the ready_playbook_inputs of this InvestigationPlaybookData.  # noqa: E501


        :return: The ready_playbook_inputs of this InvestigationPlaybookData.  # noqa: E501
        :rtype: dict(str, dict(str, object))
        """
        return self._ready_playbook_inputs

    @ready_playbook_inputs.setter
    def ready_playbook_inputs(self, ready_playbook_inputs):
        """Sets the ready_playbook_inputs of this InvestigationPlaybookData.


        :param ready_playbook_inputs: The ready_playbook_inputs of this InvestigationPlaybookData.  # noqa: E501
        :type: dict(str, dict(str, object))
        """

        self._ready_playbook_inputs = ready_playbook_inputs

    @property
    def auto_extracting(self):
        """Gets the auto_extracting of this InvestigationPlaybookData.  # noqa: E501


        :return: The auto_extracting of this InvestigationPlaybookData.  # noqa: E501
        :rtype: bool
        """
        return self._auto_extracting

    @auto_extracting.setter
    def auto_extracting(self, auto_extracting):
        """Sets the auto_extracting of this InvestigationPlaybookData.


        :param auto_extracting: The auto_extracting of this InvestigationPlaybookData.  # noqa: E501
        :type: bool
        """

        self._auto_extracting = auto_extracting

    @property
    def comment(self):
        """Gets the comment of this InvestigationPlaybookData.  # noqa: E501


        :return: The comment of this InvestigationPlaybookData.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this InvestigationPlaybookData.


        :param comment: The comment of this InvestigationPlaybookData.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def inputs(self):
        """Gets the inputs of this InvestigationPlaybookData.  # noqa: E501


        :return: The inputs of this InvestigationPlaybookData.  # noqa: E501
        :rtype: PlaybookInputs
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this InvestigationPlaybookData.


        :param inputs: The inputs of this InvestigationPlaybookData.  # noqa: E501
        :type: PlaybookInputs
        """

        self._inputs = inputs

    @property
    def investigation_id(self):
        """Gets the investigation_id of this InvestigationPlaybookData.  # noqa: E501


        :return: The investigation_id of this InvestigationPlaybookData.  # noqa: E501
        :rtype: str
        """
        return self._investigation_id

    @investigation_id.setter
    def investigation_id(self, investigation_id):
        """Sets the investigation_id of this InvestigationPlaybookData.


        :param investigation_id: The investigation_id of this InvestigationPlaybookData.  # noqa: E501
        :type: str
        """

        self._investigation_id = investigation_id

    @property
    def name(self):
        """Gets the name of this InvestigationPlaybookData.  # noqa: E501


        :return: The name of this InvestigationPlaybookData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InvestigationPlaybookData.


        :param name: The name of this InvestigationPlaybookData.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def outputs(self):
        """Gets the outputs of this InvestigationPlaybookData.  # noqa: E501


        :return: The outputs of this InvestigationPlaybookData.  # noqa: E501
        :rtype: PlaybookOutputs
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this InvestigationPlaybookData.


        :param outputs: The outputs of this InvestigationPlaybookData.  # noqa: E501
        :type: PlaybookOutputs
        """

        self._outputs = outputs

    @property
    def playbook_id(self):
        """Gets the playbook_id of this InvestigationPlaybookData.  # noqa: E501


        :return: The playbook_id of this InvestigationPlaybookData.  # noqa: E501
        :rtype: str
        """
        return self._playbook_id

    @playbook_id.setter
    def playbook_id(self, playbook_id):
        """Sets the playbook_id of this InvestigationPlaybookData.


        :param playbook_id: The playbook_id of this InvestigationPlaybookData.  # noqa: E501
        :type: str
        """

        self._playbook_id = playbook_id

    @property
    def start_date(self):
        """Gets the start_date of this InvestigationPlaybookData.  # noqa: E501


        :return: The start_date of this InvestigationPlaybookData.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this InvestigationPlaybookData.


        :param start_date: The start_date of this InvestigationPlaybookData.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def start_task_id(self):
        """Gets the start_task_id of this InvestigationPlaybookData.  # noqa: E501

        FirstTask is the root task of the playbook  # noqa: E501

        :return: The start_task_id of this InvestigationPlaybookData.  # noqa: E501
        :rtype: str
        """
        return self._start_task_id

    @start_task_id.setter
    def start_task_id(self, start_task_id):
        """Sets the start_task_id of this InvestigationPlaybookData.

        FirstTask is the root task of the playbook  # noqa: E501

        :param start_task_id: The start_task_id of this InvestigationPlaybookData.  # noqa: E501
        :type: str
        """

        self._start_task_id = start_task_id

    @property
    def state(self):
        """Gets the state of this InvestigationPlaybookData.  # noqa: E501


        :return: The state of this InvestigationPlaybookData.  # noqa: E501
        :rtype: InvestigationPlaybookState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InvestigationPlaybookData.


        :param state: The state of this InvestigationPlaybookData.  # noqa: E501
        :type: InvestigationPlaybookState
        """

        self._state = state

    @property
    def sub_playbook_inputs(self):
        """Gets the sub_playbook_inputs of this InvestigationPlaybookData.  # noqa: E501


        :return: The sub_playbook_inputs of this InvestigationPlaybookData.  # noqa: E501
        :rtype: dict(str, PlaybookInputs)
        """
        return self._sub_playbook_inputs

    @sub_playbook_inputs.setter
    def sub_playbook_inputs(self, sub_playbook_inputs):
        """Sets the sub_playbook_inputs of this InvestigationPlaybookData.


        :param sub_playbook_inputs: The sub_playbook_inputs of this InvestigationPlaybookData.  # noqa: E501
        :type: dict(str, PlaybookInputs)
        """

        self._sub_playbook_inputs = sub_playbook_inputs

    @property
    def sub_playbook_outputs(self):
        """Gets the sub_playbook_outputs of this InvestigationPlaybookData.  # noqa: E501


        :return: The sub_playbook_outputs of this InvestigationPlaybookData.  # noqa: E501
        :rtype: dict(str, PlaybookOutputs)
        """
        return self._sub_playbook_outputs

    @sub_playbook_outputs.setter
    def sub_playbook_outputs(self, sub_playbook_outputs):
        """Sets the sub_playbook_outputs of this InvestigationPlaybookData.


        :param sub_playbook_outputs: The sub_playbook_outputs of this InvestigationPlaybookData.  # noqa: E501
        :type: dict(str, PlaybookOutputs)
        """

        self._sub_playbook_outputs = sub_playbook_outputs

    @property
    def tasks(self):
        """Gets the tasks of this InvestigationPlaybookData.  # noqa: E501


        :return: The tasks of this InvestigationPlaybookData.  # noqa: E501
        :rtype: dict(str, InvestigationPlaybookTask)
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this InvestigationPlaybookData.


        :param tasks: The tasks of this InvestigationPlaybookData.  # noqa: E501
        :type: dict(str, InvestigationPlaybookTask)
        """

        self._tasks = tasks

    @property
    def view(self):
        """Gets the view of this InvestigationPlaybookData.  # noqa: E501


        :return: The view of this InvestigationPlaybookData.  # noqa: E501
        :rtype: PlaybookView
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this InvestigationPlaybookData.


        :param view: The view of this InvestigationPlaybookData.  # noqa: E501
        :type: PlaybookView
        """

        self._view = view

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvestigationPlaybookData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvestigationPlaybookData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GridColumn(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'field_calc_script': 'str',
        'is_default': 'bool',
        'is_read_only': 'bool',
        'key': 'str',
        'required': 'bool',
        'script': 'str',
        'select_values': 'list[str]',
        'type': 'str',
        'width': 'int'
    }

    attribute_map = {
        'display_name': 'displayName',
        'field_calc_script': 'fieldCalcScript',
        'is_default': 'isDefault',
        'is_read_only': 'isReadOnly',
        'key': 'key',
        'required': 'required',
        'script': 'script',
        'select_values': 'selectValues',
        'type': 'type',
        'width': 'width'
    }

    def __init__(self, display_name=None, field_calc_script=None, is_default=None, is_read_only=None, key=None, required=None, script=None, select_values=None, type=None, width=None):  # noqa: E501
        """GridColumn - a model defined in Swagger"""  # noqa: E501

        self._display_name = None
        self._field_calc_script = None
        self._is_default = None
        self._is_read_only = None
        self._key = None
        self._required = None
        self._script = None
        self._select_values = None
        self._type = None
        self._width = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        if field_calc_script is not None:
            self.field_calc_script = field_calc_script
        if is_default is not None:
            self.is_default = is_default
        if is_read_only is not None:
            self.is_read_only = is_read_only
        if key is not None:
            self.key = key
        if required is not None:
            self.required = required
        if script is not None:
            self.script = script
        if select_values is not None:
            self.select_values = select_values
        if type is not None:
            self.type = type
        if width is not None:
            self.width = width

    @property
    def display_name(self):
        """Gets the display_name of this GridColumn.  # noqa: E501


        :return: The display_name of this GridColumn.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this GridColumn.


        :param display_name: The display_name of this GridColumn.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def field_calc_script(self):
        """Gets the field_calc_script of this GridColumn.  # noqa: E501


        :return: The field_calc_script of this GridColumn.  # noqa: E501
        :rtype: str
        """
        return self._field_calc_script

    @field_calc_script.setter
    def field_calc_script(self, field_calc_script):
        """Sets the field_calc_script of this GridColumn.


        :param field_calc_script: The field_calc_script of this GridColumn.  # noqa: E501
        :type: str
        """

        self._field_calc_script = field_calc_script

    @property
    def is_default(self):
        """Gets the is_default of this GridColumn.  # noqa: E501


        :return: The is_default of this GridColumn.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this GridColumn.


        :param is_default: The is_default of this GridColumn.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def is_read_only(self):
        """Gets the is_read_only of this GridColumn.  # noqa: E501


        :return: The is_read_only of this GridColumn.  # noqa: E501
        :rtype: bool
        """
        return self._is_read_only

    @is_read_only.setter
    def is_read_only(self, is_read_only):
        """Sets the is_read_only of this GridColumn.


        :param is_read_only: The is_read_only of this GridColumn.  # noqa: E501
        :type: bool
        """

        self._is_read_only = is_read_only

    @property
    def key(self):
        """Gets the key of this GridColumn.  # noqa: E501


        :return: The key of this GridColumn.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this GridColumn.


        :param key: The key of this GridColumn.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def required(self):
        """Gets the required of this GridColumn.  # noqa: E501


        :return: The required of this GridColumn.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this GridColumn.


        :param required: The required of this GridColumn.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def script(self):
        """Gets the script of this GridColumn.  # noqa: E501


        :return: The script of this GridColumn.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this GridColumn.


        :param script: The script of this GridColumn.  # noqa: E501
        :type: str
        """

        self._script = script

    @property
    def select_values(self):
        """Gets the select_values of this GridColumn.  # noqa: E501


        :return: The select_values of this GridColumn.  # noqa: E501
        :rtype: list[str]
        """
        return self._select_values

    @select_values.setter
    def select_values(self, select_values):
        """Sets the select_values of this GridColumn.


        :param select_values: The select_values of this GridColumn.  # noqa: E501
        :type: list[str]
        """

        self._select_values = select_values

    @property
    def type(self):
        """Gets the type of this GridColumn.  # noqa: E501


        :return: The type of this GridColumn.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GridColumn.


        :param type: The type of this GridColumn.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def width(self):
        """Gets the width of this GridColumn.  # noqa: E501


        :return: The width of this GridColumn.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this GridColumn.


        :param width: The width of this GridColumn.  # noqa: E501
        :type: int
        """

        self._width = width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GridColumn, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GridColumn):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.report_automation import ReportAutomation  # noqa: F401,E501
from demisto_client.demisto_api.models.report_query import ReportQuery  # noqa: F401,E501


class Section(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'automation': 'ReportAutomation',
        'data': 'object',
        'description': 'str',
        'display_type': 'str',
        'empty_notification': 'str',
        'from_date': 'str',
        'layout': 'object',
        'query': 'ReportQuery',
        'title': 'str',
        'title_style': 'dict(str, object)',
        'to_date': 'str',
        'type': 'str'
    }

    attribute_map = {
        'automation': 'automation',
        'data': 'data',
        'description': 'description',
        'display_type': 'displayType',
        'empty_notification': 'emptyNotification',
        'from_date': 'fromDate',
        'layout': 'layout',
        'query': 'query',
        'title': 'title',
        'title_style': 'titleStyle',
        'to_date': 'toDate',
        'type': 'type'
    }

    def __init__(self, automation=None, data=None, description=None, display_type=None, empty_notification=None, from_date=None, layout=None, query=None, title=None, title_style=None, to_date=None, type=None):  # noqa: E501
        """Section - a model defined in Swagger"""  # noqa: E501

        self._automation = None
        self._data = None
        self._description = None
        self._display_type = None
        self._empty_notification = None
        self._from_date = None
        self._layout = None
        self._query = None
        self._title = None
        self._title_style = None
        self._to_date = None
        self._type = None
        self.discriminator = None

        if automation is not None:
            self.automation = automation
        if data is not None:
            self.data = data
        if description is not None:
            self.description = description
        if display_type is not None:
            self.display_type = display_type
        if empty_notification is not None:
            self.empty_notification = empty_notification
        if from_date is not None:
            self.from_date = from_date
        if layout is not None:
            self.layout = layout
        if query is not None:
            self.query = query
        if title is not None:
            self.title = title
        if title_style is not None:
            self.title_style = title_style
        if to_date is not None:
            self.to_date = to_date
        if type is not None:
            self.type = type

    @property
    def automation(self):
        """Gets the automation of this Section.  # noqa: E501


        :return: The automation of this Section.  # noqa: E501
        :rtype: ReportAutomation
        """
        return self._automation

    @automation.setter
    def automation(self, automation):
        """Sets the automation of this Section.


        :param automation: The automation of this Section.  # noqa: E501
        :type: ReportAutomation
        """

        self._automation = automation

    @property
    def data(self):
        """Gets the data of this Section.  # noqa: E501


        :return: The data of this Section.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this Section.


        :param data: The data of this Section.  # noqa: E501
        :type: object
        """

        self._data = data

    @property
    def description(self):
        """Gets the description of this Section.  # noqa: E501


        :return: The description of this Section.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Section.


        :param description: The description of this Section.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_type(self):
        """Gets the display_type of this Section.  # noqa: E501


        :return: The display_type of this Section.  # noqa: E501
        :rtype: str
        """
        return self._display_type

    @display_type.setter
    def display_type(self, display_type):
        """Sets the display_type of this Section.


        :param display_type: The display_type of this Section.  # noqa: E501
        :type: str
        """

        self._display_type = display_type

    @property
    def empty_notification(self):
        """Gets the empty_notification of this Section.  # noqa: E501


        :return: The empty_notification of this Section.  # noqa: E501
        :rtype: str
        """
        return self._empty_notification

    @empty_notification.setter
    def empty_notification(self, empty_notification):
        """Sets the empty_notification of this Section.


        :param empty_notification: The empty_notification of this Section.  # noqa: E501
        :type: str
        """

        self._empty_notification = empty_notification

    @property
    def from_date(self):
        """Gets the from_date of this Section.  # noqa: E501


        :return: The from_date of this Section.  # noqa: E501
        :rtype: str
        """
        return self._from_date

    @from_date.setter
    def from_date(self, from_date):
        """Sets the from_date of this Section.


        :param from_date: The from_date of this Section.  # noqa: E501
        :type: str
        """

        self._from_date = from_date

    @property
    def layout(self):
        """Gets the layout of this Section.  # noqa: E501


        :return: The layout of this Section.  # noqa: E501
        :rtype: object
        """
        return self._layout

    @layout.setter
    def layout(self, layout):
        """Sets the layout of this Section.


        :param layout: The layout of this Section.  # noqa: E501
        :type: object
        """

        self._layout = layout

    @property
    def query(self):
        """Gets the query of this Section.  # noqa: E501


        :return: The query of this Section.  # noqa: E501
        :rtype: ReportQuery
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this Section.


        :param query: The query of this Section.  # noqa: E501
        :type: ReportQuery
        """

        self._query = query

    @property
    def title(self):
        """Gets the title of this Section.  # noqa: E501


        :return: The title of this Section.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Section.


        :param title: The title of this Section.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def title_style(self):
        """Gets the title_style of this Section.  # noqa: E501


        :return: The title_style of this Section.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._title_style

    @title_style.setter
    def title_style(self, title_style):
        """Sets the title_style of this Section.


        :param title_style: The title_style of this Section.  # noqa: E501
        :type: dict(str, object)
        """

        self._title_style = title_style

    @property
    def to_date(self):
        """Gets the to_date of this Section.  # noqa: E501


        :return: The to_date of this Section.  # noqa: E501
        :rtype: str
        """
        return self._to_date

    @to_date.setter
    def to_date(self, to_date):
        """Sets the to_date of this Section.


        :param to_date: The to_date of this Section.  # noqa: E501
        :type: str
        """

        self._to_date = to_date

    @property
    def type(self):
        """Gets the type of this Section.  # noqa: E501


        :return: The type of this Section.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Section.


        :param type: The type of this Section.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.layout_section import LayoutSection  # noqa: F401,E501
from demisto_client.demisto_api.models.version import Version  # noqa: F401,E501


class Layout(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commit_message': 'str',
        'from_server_version': 'Version',
        'id': 'str',
        'item_version': 'Version',
        'kind': 'str',
        'modified': 'datetime',
        'name': 'str',
        'pack_id': 'str',
        'prev_kind': 'str',
        'prev_type_id': 'str',
        'primary_term': 'int',
        'propagation_labels': 'list[str]',
        'sections': 'list[LayoutSection]',
        'sequence_number': 'int',
        'should_commit': 'bool',
        'sort_values': 'list[str]',
        'system': 'bool',
        'to_server_version': 'Version',
        'type_id': 'str',
        'vc_should_ignore': 'bool',
        'version': 'int'
    }

    attribute_map = {
        'commit_message': 'commitMessage',
        'from_server_version': 'fromServerVersion',
        'id': 'id',
        'item_version': 'itemVersion',
        'kind': 'kind',
        'modified': 'modified',
        'name': 'name',
        'pack_id': 'packID',
        'prev_kind': 'prevKind',
        'prev_type_id': 'prevTypeId',
        'primary_term': 'primaryTerm',
        'propagation_labels': 'propagationLabels',
        'sections': 'sections',
        'sequence_number': 'sequenceNumber',
        'should_commit': 'shouldCommit',
        'sort_values': 'sortValues',
        'system': 'system',
        'to_server_version': 'toServerVersion',
        'type_id': 'typeId',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version'
    }

    def __init__(self, commit_message=None, from_server_version=None, id=None, item_version=None, kind=None, modified=None, name=None, pack_id=None, prev_kind=None, prev_type_id=None, primary_term=None, propagation_labels=None, sections=None, sequence_number=None, should_commit=None, sort_values=None, system=None, to_server_version=None, type_id=None, vc_should_ignore=None, version=None):  # noqa: E501
        """Layout - a model defined in Swagger"""  # noqa: E501

        self._commit_message = None
        self._from_server_version = None
        self._id = None
        self._item_version = None
        self._kind = None
        self._modified = None
        self._name = None
        self._pack_id = None
        self._prev_kind = None
        self._prev_type_id = None
        self._primary_term = None
        self._propagation_labels = None
        self._sections = None
        self._sequence_number = None
        self._should_commit = None
        self._sort_values = None
        self._system = None
        self._to_server_version = None
        self._type_id = None
        self._vc_should_ignore = None
        self._version = None
        self.discriminator = None

        if commit_message is not None:
            self.commit_message = commit_message
        if from_server_version is not None:
            self.from_server_version = from_server_version
        if id is not None:
            self.id = id
        if item_version is not None:
            self.item_version = item_version
        if kind is not None:
            self.kind = kind
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if pack_id is not None:
            self.pack_id = pack_id
        if prev_kind is not None:
            self.prev_kind = prev_kind
        if prev_type_id is not None:
            self.prev_type_id = prev_type_id
        if primary_term is not None:
            self.primary_term = primary_term
        if propagation_labels is not None:
            self.propagation_labels = propagation_labels
        if sections is not None:
            self.sections = sections
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if should_commit is not None:
            self.should_commit = should_commit
        if sort_values is not None:
            self.sort_values = sort_values
        if system is not None:
            self.system = system
        if to_server_version is not None:
            self.to_server_version = to_server_version
        if type_id is not None:
            self.type_id = type_id
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version

    @property
    def commit_message(self):
        """Gets the commit_message of this Layout.  # noqa: E501


        :return: The commit_message of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this Layout.


        :param commit_message: The commit_message of this Layout.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def from_server_version(self):
        """Gets the from_server_version of this Layout.  # noqa: E501


        :return: The from_server_version of this Layout.  # noqa: E501
        :rtype: Version
        """
        return self._from_server_version

    @from_server_version.setter
    def from_server_version(self, from_server_version):
        """Sets the from_server_version of this Layout.


        :param from_server_version: The from_server_version of this Layout.  # noqa: E501
        :type: Version
        """

        self._from_server_version = from_server_version

    @property
    def id(self):
        """Gets the id of this Layout.  # noqa: E501


        :return: The id of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Layout.


        :param id: The id of this Layout.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def item_version(self):
        """Gets the item_version of this Layout.  # noqa: E501


        :return: The item_version of this Layout.  # noqa: E501
        :rtype: Version
        """
        return self._item_version

    @item_version.setter
    def item_version(self, item_version):
        """Sets the item_version of this Layout.


        :param item_version: The item_version of this Layout.  # noqa: E501
        :type: Version
        """

        self._item_version = item_version

    @property
    def kind(self):
        """Gets the kind of this Layout.  # noqa: E501


        :return: The kind of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this Layout.


        :param kind: The kind of this Layout.  # noqa: E501
        :type: str
        """

        self._kind = kind

    @property
    def modified(self):
        """Gets the modified of this Layout.  # noqa: E501


        :return: The modified of this Layout.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Layout.


        :param modified: The modified of this Layout.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this Layout.  # noqa: E501


        :return: The name of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Layout.


        :param name: The name of this Layout.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def pack_id(self):
        """Gets the pack_id of this Layout.  # noqa: E501


        :return: The pack_id of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._pack_id

    @pack_id.setter
    def pack_id(self, pack_id):
        """Sets the pack_id of this Layout.


        :param pack_id: The pack_id of this Layout.  # noqa: E501
        :type: str
        """

        self._pack_id = pack_id

    @property
    def prev_kind(self):
        """Gets the prev_kind of this Layout.  # noqa: E501


        :return: The prev_kind of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._prev_kind

    @prev_kind.setter
    def prev_kind(self, prev_kind):
        """Sets the prev_kind of this Layout.


        :param prev_kind: The prev_kind of this Layout.  # noqa: E501
        :type: str
        """

        self._prev_kind = prev_kind

    @property
    def prev_type_id(self):
        """Gets the prev_type_id of this Layout.  # noqa: E501


        :return: The prev_type_id of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._prev_type_id

    @prev_type_id.setter
    def prev_type_id(self, prev_type_id):
        """Sets the prev_type_id of this Layout.


        :param prev_type_id: The prev_type_id of this Layout.  # noqa: E501
        :type: str
        """

        self._prev_type_id = prev_type_id

    @property
    def primary_term(self):
        """Gets the primary_term of this Layout.  # noqa: E501


        :return: The primary_term of this Layout.  # noqa: E501
        :rtype: int
        """
        return self._primary_term

    @primary_term.setter
    def primary_term(self, primary_term):
        """Sets the primary_term of this Layout.


        :param primary_term: The primary_term of this Layout.  # noqa: E501
        :type: int
        """

        self._primary_term = primary_term

    @property
    def propagation_labels(self):
        """Gets the propagation_labels of this Layout.  # noqa: E501


        :return: The propagation_labels of this Layout.  # noqa: E501
        :rtype: list[str]
        """
        return self._propagation_labels

    @propagation_labels.setter
    def propagation_labels(self, propagation_labels):
        """Sets the propagation_labels of this Layout.


        :param propagation_labels: The propagation_labels of this Layout.  # noqa: E501
        :type: list[str]
        """

        self._propagation_labels = propagation_labels

    @property
    def sections(self):
        """Gets the sections of this Layout.  # noqa: E501


        :return: The sections of this Layout.  # noqa: E501
        :rtype: list[LayoutSection]
        """
        return self._sections

    @sections.setter
    def sections(self, sections):
        """Sets the sections of this Layout.


        :param sections: The sections of this Layout.  # noqa: E501
        :type: list[LayoutSection]
        """

        self._sections = sections

    @property
    def sequence_number(self):
        """Gets the sequence_number of this Layout.  # noqa: E501


        :return: The sequence_number of this Layout.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this Layout.


        :param sequence_number: The sequence_number of this Layout.  # noqa: E501
        :type: int
        """

        self._sequence_number = sequence_number

    @property
    def should_commit(self):
        """Gets the should_commit of this Layout.  # noqa: E501


        :return: The should_commit of this Layout.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this Layout.


        :param should_commit: The should_commit of this Layout.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sort_values(self):
        """Gets the sort_values of this Layout.  # noqa: E501


        :return: The sort_values of this Layout.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Layout.


        :param sort_values: The sort_values of this Layout.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def system(self):
        """Gets the system of this Layout.  # noqa: E501


        :return: The system of this Layout.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this Layout.


        :param system: The system of this Layout.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def to_server_version(self):
        """Gets the to_server_version of this Layout.  # noqa: E501


        :return: The to_server_version of this Layout.  # noqa: E501
        :rtype: Version
        """
        return self._to_server_version

    @to_server_version.setter
    def to_server_version(self, to_server_version):
        """Sets the to_server_version of this Layout.


        :param to_server_version: The to_server_version of this Layout.  # noqa: E501
        :type: Version
        """

        self._to_server_version = to_server_version

    @property
    def type_id(self):
        """Gets the type_id of this Layout.  # noqa: E501


        :return: The type_id of this Layout.  # noqa: E501
        :rtype: str
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this Layout.


        :param type_id: The type_id of this Layout.  # noqa: E501
        :type: str
        """

        self._type_id = type_id

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this Layout.  # noqa: E501


        :return: The vc_should_ignore of this Layout.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this Layout.


        :param vc_should_ignore: The vc_should_ignore of this Layout.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this Layout.  # noqa: E501


        :return: The version of this Layout.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Layout.


        :param version: The version of this Layout.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Layout, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Layout):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.argument import Argument  # noqa: F401,E501
from demisto_client.demisto_api.models.important import Important  # noqa: F401,E501
from demisto_client.demisto_api.models.output import Output  # noqa: F401,E501


class Command(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'arguments': 'list[Argument]',
        'cartesian': 'bool',
        'deprecated': 'bool',
        'description': 'str',
        'execution': 'bool',
        'hidden': 'bool',
        'important': 'list[Important]',
        'name': 'str',
        'outputs': 'list[Output]',
        'permitted': 'bool',
        'sensitive': 'bool',
        'timeout': 'int'
    }

    attribute_map = {
        'arguments': 'arguments',
        'cartesian': 'cartesian',
        'deprecated': 'deprecated',
        'description': 'description',
        'execution': 'execution',
        'hidden': 'hidden',
        'important': 'important',
        'name': 'name',
        'outputs': 'outputs',
        'permitted': 'permitted',
        'sensitive': 'sensitive',
        'timeout': 'timeout'
    }

    def __init__(self, arguments=None, cartesian=None, deprecated=None, description=None, execution=None, hidden=None, important=None, name=None, outputs=None, permitted=None, sensitive=None, timeout=None):  # noqa: E501
        """Command - a model defined in Swagger"""  # noqa: E501

        self._arguments = None
        self._cartesian = None
        self._deprecated = None
        self._description = None
        self._execution = None
        self._hidden = None
        self._important = None
        self._name = None
        self._outputs = None
        self._permitted = None
        self._sensitive = None
        self._timeout = None
        self.discriminator = None

        if arguments is not None:
            self.arguments = arguments
        if cartesian is not None:
            self.cartesian = cartesian
        if deprecated is not None:
            self.deprecated = deprecated
        if description is not None:
            self.description = description
        if execution is not None:
            self.execution = execution
        if hidden is not None:
            self.hidden = hidden
        if important is not None:
            self.important = important
        if name is not None:
            self.name = name
        if outputs is not None:
            self.outputs = outputs
        if permitted is not None:
            self.permitted = permitted
        if sensitive is not None:
            self.sensitive = sensitive
        if timeout is not None:
            self.timeout = timeout

    @property
    def arguments(self):
        """Gets the arguments of this Command.  # noqa: E501


        :return: The arguments of this Command.  # noqa: E501
        :rtype: list[Argument]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this Command.


        :param arguments: The arguments of this Command.  # noqa: E501
        :type: list[Argument]
        """

        self._arguments = arguments

    @property
    def cartesian(self):
        """Gets the cartesian of this Command.  # noqa: E501


        :return: The cartesian of this Command.  # noqa: E501
        :rtype: bool
        """
        return self._cartesian

    @cartesian.setter
    def cartesian(self, cartesian):
        """Sets the cartesian of this Command.


        :param cartesian: The cartesian of this Command.  # noqa: E501
        :type: bool
        """

        self._cartesian = cartesian

    @property
    def deprecated(self):
        """Gets the deprecated of this Command.  # noqa: E501


        :return: The deprecated of this Command.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this Command.


        :param deprecated: The deprecated of this Command.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def description(self):
        """Gets the description of this Command.  # noqa: E501


        :return: The description of this Command.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Command.


        :param description: The description of this Command.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def execution(self):
        """Gets the execution of this Command.  # noqa: E501


        :return: The execution of this Command.  # noqa: E501
        :rtype: bool
        """
        return self._execution

    @execution.setter
    def execution(self, execution):
        """Sets the execution of this Command.


        :param execution: The execution of this Command.  # noqa: E501
        :type: bool
        """

        self._execution = execution

    @property
    def hidden(self):
        """Gets the hidden of this Command.  # noqa: E501


        :return: The hidden of this Command.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this Command.


        :param hidden: The hidden of this Command.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def important(self):
        """Gets the important of this Command.  # noqa: E501


        :return: The important of this Command.  # noqa: E501
        :rtype: list[Important]
        """
        return self._important

    @important.setter
    def important(self, important):
        """Sets the important of this Command.


        :param important: The important of this Command.  # noqa: E501
        :type: list[Important]
        """

        self._important = important

    @property
    def name(self):
        """Gets the name of this Command.  # noqa: E501


        :return: The name of this Command.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Command.


        :param name: The name of this Command.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def outputs(self):
        """Gets the outputs of this Command.  # noqa: E501


        :return: The outputs of this Command.  # noqa: E501
        :rtype: list[Output]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this Command.


        :param outputs: The outputs of this Command.  # noqa: E501
        :type: list[Output]
        """

        self._outputs = outputs

    @property
    def permitted(self):
        """Gets the permitted of this Command.  # noqa: E501


        :return: The permitted of this Command.  # noqa: E501
        :rtype: bool
        """
        return self._permitted

    @permitted.setter
    def permitted(self, permitted):
        """Sets the permitted of this Command.


        :param permitted: The permitted of this Command.  # noqa: E501
        :type: bool
        """

        self._permitted = permitted

    @property
    def sensitive(self):
        """Gets the sensitive of this Command.  # noqa: E501


        :return: The sensitive of this Command.  # noqa: E501
        :rtype: bool
        """
        return self._sensitive

    @sensitive.setter
    def sensitive(self, sensitive):
        """Sets the sensitive of this Command.


        :param sensitive: The sensitive of this Command.  # noqa: E501
        :type: bool
        """

        self._sensitive = sensitive

    @property
    def timeout(self):
        """Gets the timeout of this Command.  # noqa: E501


        :return: The timeout of this Command.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this Command.


        :param timeout: The timeout of this Command.  # noqa: E501
        :type: int
        """

        self._timeout = timeout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Command, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Command):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.period import Period  # noqa: F401,E501
from demisto_client.demisto_api.models.widget_cells import WidgetCells  # noqa: F401,E501


class Dashboard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commit_message': 'str',
        'from_date': 'datetime',
        'from_date_license': 'datetime',
        'id': 'str',
        'is_common': 'bool',
        'layout': 'WidgetCells',
        'modified': 'datetime',
        'name': 'str',
        'owner': 'str',
        'period': 'Period',
        'prev_name': 'str',
        'shared': 'bool',
        'should_commit': 'bool',
        'sort_values': 'list[str]',
        'system': 'bool',
        'to_date': 'datetime',
        'vc_should_ignore': 'bool',
        'version': 'int'
    }

    attribute_map = {
        'commit_message': 'commitMessage',
        'from_date': 'fromDate',
        'from_date_license': 'fromDateLicense',
        'id': 'id',
        'is_common': 'isCommon',
        'layout': 'layout',
        'modified': 'modified',
        'name': 'name',
        'owner': 'owner',
        'period': 'period',
        'prev_name': 'prevName',
        'shared': 'shared',
        'should_commit': 'shouldCommit',
        'sort_values': 'sortValues',
        'system': 'system',
        'to_date': 'toDate',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version'
    }

    def __init__(self, commit_message=None, from_date=None, from_date_license=None, id=None, is_common=None, layout=None, modified=None, name=None, owner=None, period=None, prev_name=None, shared=None, should_commit=None, sort_values=None, system=None, to_date=None, vc_should_ignore=None, version=None):  # noqa: E501
        """Dashboard - a model defined in Swagger"""  # noqa: E501

        self._commit_message = None
        self._from_date = None
        self._from_date_license = None
        self._id = None
        self._is_common = None
        self._layout = None
        self._modified = None
        self._name = None
        self._owner = None
        self._period = None
        self._prev_name = None
        self._shared = None
        self._should_commit = None
        self._sort_values = None
        self._system = None
        self._to_date = None
        self._vc_should_ignore = None
        self._version = None
        self.discriminator = None

        if commit_message is not None:
            self.commit_message = commit_message
        if from_date is not None:
            self.from_date = from_date
        if from_date_license is not None:
            self.from_date_license = from_date_license
        if id is not None:
            self.id = id
        if is_common is not None:
            self.is_common = is_common
        if layout is not None:
            self.layout = layout
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if owner is not None:
            self.owner = owner
        if period is not None:
            self.period = period
        if prev_name is not None:
            self.prev_name = prev_name
        if shared is not None:
            self.shared = shared
        if should_commit is not None:
            self.should_commit = should_commit
        if sort_values is not None:
            self.sort_values = sort_values
        if system is not None:
            self.system = system
        if to_date is not None:
            self.to_date = to_date
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version

    @property
    def commit_message(self):
        """Gets the commit_message of this Dashboard.  # noqa: E501


        :return: The commit_message of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this Dashboard.


        :param commit_message: The commit_message of this Dashboard.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def from_date(self):
        """Gets the from_date of this Dashboard.  # noqa: E501


        :return: The from_date of this Dashboard.  # noqa: E501
        :rtype: datetime
        """
        return self._from_date

    @from_date.setter
    def from_date(self, from_date):
        """Sets the from_date of this Dashboard.


        :param from_date: The from_date of this Dashboard.  # noqa: E501
        :type: datetime
        """

        self._from_date = from_date

    @property
    def from_date_license(self):
        """Gets the from_date_license of this Dashboard.  # noqa: E501


        :return: The from_date_license of this Dashboard.  # noqa: E501
        :rtype: datetime
        """
        return self._from_date_license

    @from_date_license.setter
    def from_date_license(self, from_date_license):
        """Sets the from_date_license of this Dashboard.


        :param from_date_license: The from_date_license of this Dashboard.  # noqa: E501
        :type: datetime
        """

        self._from_date_license = from_date_license

    @property
    def id(self):
        """Gets the id of this Dashboard.  # noqa: E501


        :return: The id of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Dashboard.


        :param id: The id of this Dashboard.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_common(self):
        """Gets the is_common of this Dashboard.  # noqa: E501


        :return: The is_common of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._is_common

    @is_common.setter
    def is_common(self, is_common):
        """Sets the is_common of this Dashboard.


        :param is_common: The is_common of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._is_common = is_common

    @property
    def layout(self):
        """Gets the layout of this Dashboard.  # noqa: E501


        :return: The layout of this Dashboard.  # noqa: E501
        :rtype: WidgetCells
        """
        return self._layout

    @layout.setter
    def layout(self, layout):
        """Sets the layout of this Dashboard.


        :param layout: The layout of this Dashboard.  # noqa: E501
        :type: WidgetCells
        """

        self._layout = layout

    @property
    def modified(self):
        """Gets the modified of this Dashboard.  # noqa: E501


        :return: The modified of this Dashboard.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Dashboard.


        :param modified: The modified of this Dashboard.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this Dashboard.  # noqa: E501


        :return: The name of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Dashboard.


        :param name: The name of this Dashboard.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def owner(self):
        """Gets the owner of this Dashboard.  # noqa: E501


        :return: The owner of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this Dashboard.


        :param owner: The owner of this Dashboard.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def period(self):
        """Gets the period of this Dashboard.  # noqa: E501


        :return: The period of this Dashboard.  # noqa: E501
        :rtype: Period
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this Dashboard.


        :param period: The period of this Dashboard.  # noqa: E501
        :type: Period
        """

        self._period = period

    @property
    def prev_name(self):
        """Gets the prev_name of this Dashboard.  # noqa: E501


        :return: The prev_name of this Dashboard.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this Dashboard.


        :param prev_name: The prev_name of this Dashboard.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def shared(self):
        """Gets the shared of this Dashboard.  # noqa: E501


        :return: The shared of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._shared

    @shared.setter
    def shared(self, shared):
        """Sets the shared of this Dashboard.


        :param shared: The shared of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._shared = shared

    @property
    def should_commit(self):
        """Gets the should_commit of this Dashboard.  # noqa: E501


        :return: The should_commit of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this Dashboard.


        :param should_commit: The should_commit of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sort_values(self):
        """Gets the sort_values of this Dashboard.  # noqa: E501


        :return: The sort_values of this Dashboard.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Dashboard.


        :param sort_values: The sort_values of this Dashboard.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def system(self):
        """Gets the system of this Dashboard.  # noqa: E501


        :return: The system of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this Dashboard.


        :param system: The system of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def to_date(self):
        """Gets the to_date of this Dashboard.  # noqa: E501


        :return: The to_date of this Dashboard.  # noqa: E501
        :rtype: datetime
        """
        return self._to_date

    @to_date.setter
    def to_date(self, to_date):
        """Sets the to_date of this Dashboard.


        :param to_date: The to_date of this Dashboard.  # noqa: E501
        :type: datetime
        """

        self._to_date = to_date

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this Dashboard.  # noqa: E501


        :return: The vc_should_ignore of this Dashboard.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this Dashboard.


        :param vc_should_ignore: The vc_should_ignore of this Dashboard.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this Dashboard.  # noqa: E501


        :return: The version of this Dashboard.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Dashboard.


        :param version: The version of this Dashboard.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Dashboard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Dashboard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import pprint
from demisto_client.demisto_api import rest

UPDATE_AUTOMATION_EXAMPLE_PATH = './examples/update_automation_example.py'


class Response:
    def __init__(self, data):
        self.data = data


def test_run_update_automation_example(mocker):
    """
    Given: A demisto instance.
    When: Running the update_automation_example.py script.
    Then: Ensure no errors are raised.
    """
    mocker.patch.object(rest.RESTClientObject, 'POST', return_value=Response(data='{ok}'))
    mocked_pprint = mocker.patch.object(pprint, 'pprint')
    with open(UPDATE_AUTOMATION_EXAMPLE_PATH) as example_file:
        exec(example_file.read())

    mocked_pprint.assert_called_once()



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.task_state import TaskState  # noqa: F401,E501


class InvPlaybookTaskCompleteData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'arguments': 'dict(str, object)',
        'completed_by': 'str',
        'completed_count': 'int',
        'completed_date': 'datetime',
        'entries': 'list[str]',
        'input': 'str',
        'outputs': 'dict(str, object)',
        'playbook_inputs': 'dict(str, object)',
        'start_date': 'datetime',
        'state': 'TaskState',
        'will_not_execute_count': 'int'
    }

    attribute_map = {
        'arguments': 'arguments',
        'completed_by': 'completedBy',
        'completed_count': 'completedCount',
        'completed_date': 'completedDate',
        'entries': 'entries',
        'input': 'input',
        'outputs': 'outputs',
        'playbook_inputs': 'playbookInputs',
        'start_date': 'startDate',
        'state': 'state',
        'will_not_execute_count': 'willNotExecuteCount'
    }

    def __init__(self, arguments=None, completed_by=None, completed_count=None, completed_date=None, entries=None, input=None, outputs=None, playbook_inputs=None, start_date=None, state=None, will_not_execute_count=None):  # noqa: E501
        """InvPlaybookTaskCompleteData - a model defined in Swagger"""  # noqa: E501

        self._arguments = None
        self._completed_by = None
        self._completed_count = None
        self._completed_date = None
        self._entries = None
        self._input = None
        self._outputs = None
        self._playbook_inputs = None
        self._start_date = None
        self._state = None
        self._will_not_execute_count = None
        self.discriminator = None

        if arguments is not None:
            self.arguments = arguments
        if completed_by is not None:
            self.completed_by = completed_by
        if completed_count is not None:
            self.completed_count = completed_count
        if completed_date is not None:
            self.completed_date = completed_date
        if entries is not None:
            self.entries = entries
        if input is not None:
            self.input = input
        if outputs is not None:
            self.outputs = outputs
        if playbook_inputs is not None:
            self.playbook_inputs = playbook_inputs
        if start_date is not None:
            self.start_date = start_date
        if state is not None:
            self.state = state
        if will_not_execute_count is not None:
            self.will_not_execute_count = will_not_execute_count

    @property
    def arguments(self):
        """Gets the arguments of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The arguments of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this InvPlaybookTaskCompleteData.


        :param arguments: The arguments of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: dict(str, object)
        """

        self._arguments = arguments

    @property
    def completed_by(self):
        """Gets the completed_by of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The completed_by of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: str
        """
        return self._completed_by

    @completed_by.setter
    def completed_by(self, completed_by):
        """Sets the completed_by of this InvPlaybookTaskCompleteData.


        :param completed_by: The completed_by of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: str
        """

        self._completed_by = completed_by

    @property
    def completed_count(self):
        """Gets the completed_count of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The completed_count of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: int
        """
        return self._completed_count

    @completed_count.setter
    def completed_count(self, completed_count):
        """Sets the completed_count of this InvPlaybookTaskCompleteData.


        :param completed_count: The completed_count of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: int
        """

        self._completed_count = completed_count

    @property
    def completed_date(self):
        """Gets the completed_date of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The completed_date of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_date

    @completed_date.setter
    def completed_date(self, completed_date):
        """Sets the completed_date of this InvPlaybookTaskCompleteData.


        :param completed_date: The completed_date of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: datetime
        """

        self._completed_date = completed_date

    @property
    def entries(self):
        """Gets the entries of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The entries of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: list[str]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """Sets the entries of this InvPlaybookTaskCompleteData.


        :param entries: The entries of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: list[str]
        """

        self._entries = entries

    @property
    def input(self):
        """Gets the input of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The input of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this InvPlaybookTaskCompleteData.


        :param input: The input of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: str
        """

        self._input = input

    @property
    def outputs(self):
        """Gets the outputs of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The outputs of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this InvPlaybookTaskCompleteData.


        :param outputs: The outputs of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: dict(str, object)
        """

        self._outputs = outputs

    @property
    def playbook_inputs(self):
        """Gets the playbook_inputs of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The playbook_inputs of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._playbook_inputs

    @playbook_inputs.setter
    def playbook_inputs(self, playbook_inputs):
        """Sets the playbook_inputs of this InvPlaybookTaskCompleteData.


        :param playbook_inputs: The playbook_inputs of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: dict(str, object)
        """

        self._playbook_inputs = playbook_inputs

    @property
    def start_date(self):
        """Gets the start_date of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The start_date of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this InvPlaybookTaskCompleteData.


        :param start_date: The start_date of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def state(self):
        """Gets the state of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The state of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: TaskState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InvPlaybookTaskCompleteData.


        :param state: The state of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: TaskState
        """

        self._state = state

    @property
    def will_not_execute_count(self):
        """Gets the will_not_execute_count of this InvPlaybookTaskCompleteData.  # noqa: E501


        :return: The will_not_execute_count of this InvPlaybookTaskCompleteData.  # noqa: E501
        :rtype: int
        """
        return self._will_not_execute_count

    @will_not_execute_count.setter
    def will_not_execute_count(self, will_not_execute_count):
        """Sets the will_not_execute_count of this InvPlaybookTaskCompleteData.


        :param will_not_execute_count: The will_not_execute_count of this InvPlaybookTaskCompleteData.  # noqa: E501
        :type: int
        """

        self._will_not_execute_count = will_not_execute_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvPlaybookTaskCompleteData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvPlaybookTaskCompleteData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
